aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc-srvsvc.c
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
commitfeab79e32878302a87c7d22c52a2d5a255dbd3e9 (patch)
tree934f82dcbdd30f8c04d96b4215dbb0a6b8bc437e /epan/dissectors/packet-dcerpc-srvsvc.c
parent58a0b106989d8278670d78fba86dd4585c3be52d (diff)
change a whole bunch of ethereal into wireshark
svn path=/trunk/; revision=18196
Diffstat (limited to 'epan/dissectors/packet-dcerpc-srvsvc.c')
-rw-r--r--epan/dissectors/packet-dcerpc-srvsvc.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/epan/dissectors/packet-dcerpc-srvsvc.c b/epan/dissectors/packet-dcerpc-srvsvc.c
index 092af7a59b..a91a75b6de 100644
--- a/epan/dissectors/packet-dcerpc-srvsvc.c
+++ b/epan/dissectors/packet-dcerpc-srvsvc.c
@@ -11,8 +11,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -5445,7 +5445,7 @@ srvsvc_dissect_DISK_INFO_0(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
/* this call is to make ethereal eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;
@@ -6233,7 +6233,7 @@ srvsvc_dissect_netrpathcanonicalize_reply(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
/* this call is to make ethereal eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;
@@ -6377,7 +6377,7 @@ srvsvc_dissect_netrnamecanonicalize_reply(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
/* this call is to make ethereal eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;
@@ -7027,7 +7027,7 @@ proto_register_dcerpc_srvsvc(void)
BASE_HEX, NULL, 0x0, "Permissions", HFILL}},
{ &hf_srvsvc_dfs_root_flags,
{ "DFS Root Flags", "srvsvc.dfs_root_flags", FT_UINT32,
- BASE_HEX, NULL, 0x0, "DFS Root Flags. Contact ethereal developers if you know what the bits are", HFILL}},
+ BASE_HEX, NULL, 0x0, "DFS Root Flags. Contact wireshark developers if you know what the bits are", HFILL}},
{ &hf_srvsvc_policy,
{ "Policy", "srvsvc.policy", FT_UINT32,
BASE_HEX, NULL, 0x0, "Policy", HFILL}},
@@ -11,8 +11,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
@@ -5445,7 +5445,7 @@ srvsvc_dissect_DISK_INFO_0(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
- /* this call is to make ethereal eat the array header for the conformant run */
+ /* this call is to make wireshark eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;
@@ -6233,7 +6233,7 @@ srvsvc_dissect_netrpathcanonicalize_reply(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
- /* this call is to make ethereal eat the array header for the conformant run */
+ /* this call is to make wireshark eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;
@@ -6377,7 +6377,7 @@ srvsvc_dissect_netrnamecanonicalize_reply(tvbuff_t *tvb, int offset,
di=pinfo->private_data;
if(di->conformant_run){
- /* this call is to make ethereal eat the array header for the conformant run */
+ /* this call is to make wireshark eat the array header for the conformant run */
offset =dissect_ndr_ucarray(tvb, offset, pinfo, tree, drep, NULL);
return offset;